@@ -1,12 +1,11 @@
 sample.fw <-
 function(X, nc=1e4, n=1e3)
 {
-	cat("Note: \n")
-	cat("This sampling algorithm may take from a few minutes to a few hours \n")
-
 	if(is.data.frame(X) | is.matrix(X)) X <- as.data.frame(X)
-	else stop("\'X\' must be either a matrix or a data.frame.\n")
+	else stop("\'X\' must be either a matrix or a data.frame.\n")	
 	
+	if(nrow(X) < nc) stop("The number of rows in \'X\' should be larger than \'nc\'")
+
 	ndp <- nrow(X)
 	X <- X[order(X[,1], decreasing=TRUE), ]
 	X$g <- gl(nc, ndp/nc)	
@@ -17,5 +16,7 @@ function(X, nc=1e4, n=1e3)
 	sind <- unlist( mapply("+", as.list( c(0, cumsum(rep(ndp/nc, nc)))[-(nc+1)] ), scnt) )
 	X <- X[sind, c(-1, -length(names(X)))]
 	row.names(X) <- NULL
+	
+	class(X) <- c("samplefwl", "data.frame")
 	return(X)
 }
